@@ -3,7 +3,7 @@ from ckeditor_uploader.fields import RichTextUploadingField
 from taggit.managers import TaggableManager
 from django.contrib.auth import get_user_model
 from django.dispatch import receiver
-from django.db.models.signals import pre_save
+from django.db.models.signals import pre_save, post_save
 from blog.helpers import slug_generator
 
 
@@ -99,6 +99,7 @@ class Article(AbstractCommonFields):
     like = models.ManyToManyField(User, blank=True, null=True, related_name='like')
     comments = models.ManyToManyField('Comment', blank=True, null=True, related_name='comment')
     allow_comments = models.BooleanField(default=False)
+    change_status_on = models.DateTimeField(blank=True, null=True)
 
     def total_likes(self):
         return self.like.all().count()
@@ -131,6 +132,13 @@ def _pre_save_receiver(sender, instance, *args, **kwargs):
         instance.slug = slug_generator(instance)
 
 
+@receiver(post_save, sender=Article)
+def _post_save_receiver(sender, instance, *args, **kwargs):
+    from task_app.helpers import create_or_update_task
+    if instance.change_status_on:
+        create_or_update_task(instance)
+
+
 class Comment(AbstractCommonFields):
     user = models.ForeignKey(User, on_delete=models.CASCADE)
     body = models.TextField()
