@@ -93,9 +93,8 @@ class ArticleViewSet(viewsets.ModelViewSet):
         3. if it found only 'status' then it will return all the articles of the given status
         4. if it does not found 'status' and 'subcategory_slug' then it will return all the active articles
         '''
-        queryset = self.get_queryset().filter(
-            Q(subcategory__slug=request.GET.get('subcategory_slug') &
-                                Q(status__exact=request.GET.get('status', None) or 'active'))) \
+        queryset = self.get_queryset().filter(Q(subcategory__slug=request.GET.get('subcategory_slug')) &
+                                              Q(status__exact=request.GET.get('status', None) or 'active')) \
             if request.GET.get('subcategory_slug', None) \
             else self.get_queryset().filter(status__exact=request.GET.get('status', None) or 'active')
         return response.Response(self.get_serializer_class()(queryset, many=True).data,
